@@ -15,24 +15,32 @@
 
 import importlib.util
 import inspect
+import sys
 
 from rpe.policy import Evaluation, Policy
 
 
 class PythonPolicyEngine:
 
-    _policies={}
+    counter = 0
 
     def __init__(self, package_path):
+
+        self._policies={}
         self.package_path = package_path
+        PythonPolicyEngine.counter += 1
+        self.package_name = 'rpe.plugins.policies.py_' + str(PythonPolicyEngine.counter)
+
         self._load_policies()
 
     def _load_policies(self):
         spec = importlib.util.spec_from_file_location(
-            "pypol",
+            self.package_name,
             "{}/__init__.py".format(self.package_path)
         )
         module = importlib.util.module_from_spec(spec)
+        sys.modules[self.package_name] = module
+
         spec.loader.exec_module(module)
 
         for name, obj in inspect.getmembers(module):
@@ -63,17 +71,31 @@ class PythonPolicyEngine:
             self._policies.items()
         ))
 
-        evals = [
-            Evaluation(
-                resource=resource,
-                engine=self,
-                policy_id=policy_name,
-                compliant=policy_cls.compliant(resource),
-                excluded=policy_cls.excluded(resource),
-                remediable=hasattr(policy_cls, 'remediate')
-            )
-            for policy_name,policy_cls in matched_policies.items()
-        ]
+        # Loop over policy and build evals, so we can catch exceptions
+
+        evals = []
+
+        for policy_name, policy_cls in matched_policies.items():
+            try:
+
+                # Ensure that these are boolean
+                compliant = policy_cls.compliant(resource) is True
+                excluded = policy_cls.excluded(resource) is True
+
+                ev = Evaluation(
+                    resource=resource,
+                    engine=self,
+                    policy_id=policy_name,
+                    compliant=compliant,
+                    excluded=excluded,
+                    remediable=hasattr(policy_cls, 'remediate')
+                )
+
+                evals.append(ev)
+
+            # These are user-provided modules, we need to catch any exception
+            except Exception as e:
+                print(f'Evaluation exception. Policy: {policy_name}, Message: {str(e)}')
 
         return evals
 
