@@ -26,9 +26,11 @@ from rpe.resources.gcp import GcpBigtableInstance
 from rpe.resources.gcp import GcpCloudFunction
 from rpe.resources.gcp import GcpComputeInstance
 from rpe.resources.gcp import GcpComputeDisks
+from rpe.resources.gcp import GcpDatafusionInstance
 from rpe.resources.gcp import GcpDataprocCluster
 from rpe.resources.gcp import GcpGkeCluster
 from rpe.resources.gcp import GcpGkeClusterNodepool
+from rpe.resources.gcp import GcpOrganization
 from rpe.resources.gcp import GcpProject
 from rpe.resources.gcp import GcpProjectService
 from rpe.resources.gcp import GcpPubsubSubscription
@@ -101,6 +103,13 @@ test_cases = [
         },
         resource_cls=GcpComputeFirewall
     ),
+    CaiTestCase(
+        data={
+            "name": "//datafusion.googleapis.com/projects/test-project/locations/us-central1/instances/test-resource",
+            "asset_type": "datafusion.googleapis.com/Instance",
+        },
+        resource_cls=GcpDatafusionInstance
+    ),
     CaiTestCase(
         data={
             "name": "//dataproc.googleapis.com/projects/test-project/regions/us-central1/clusters/test-resource",
@@ -150,6 +159,13 @@ test_cases = [
         },
         resource_cls=GcpSqlInstance
     ),
+    CaiTestCase(
+        data={
+            "name": "//cloudresourcemanager.googleapis.com/organizations/test-resource",
+            "asset_type": "cloudresourcemanager.googleapis.com/Organization",
+        },
+        resource_cls=GcpOrganization
+    ),
     CaiTestCase(
         data={
             "name": "//cloudresourcemanager.googleapis.com/projects/test-resource",
